aboutsummaryrefslogtreecommitdiffstatshomepage
path: root/out.h
diff options
context:
space:
mode:
authorIngo Schwarze <schwarze@openbsd.org>2017-06-08 18:11:22 +0000
committerIngo Schwarze <schwarze@openbsd.org>2017-06-08 18:11:22 +0000
commit487d956e07013bc929ab478a0503246df414b00a (patch)
tree22c2d5abff010bc035dd6d8ee6c0d64f46a9b627 /out.h
parent789580a2a2366243d622766fdadd094931ca6596 (diff)
downloadmandoc-487d956e07013bc929ab478a0503246df414b00a.tar.gz
mandoc-487d956e07013bc929ab478a0503246df414b00a.tar.zst
mandoc-487d956e07013bc929ab478a0503246df414b00a.zip
Implement w layout specifier (minimum column width).
Improve width calculation of text blocks. Reduces the groff/mandoc diff in Base+Xenocara by about 800 lines.
Diffstat (limited to 'out.h')
-rw-r--r--out.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/out.h b/out.h
index 7cb95a7d..ac617b32 100644
--- a/out.h
+++ b/out.h
@@ -1,4 +1,4 @@
-/* $Id: out.h,v 1.28 2017/06/08 12:54:58 schwarze Exp $ */
+/* $Id: out.h,v 1.29 2017/06/08 18:11:22 schwarze Exp $ */
/*
* Copyright (c) 2009, 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
* Copyright (c) 2014, 2017 Ingo Schwarze <schwarze@openbsd.org>
@@ -41,14 +41,16 @@ struct roffsu {
double scale;
};
+typedef size_t (*tbl_sulen)(const struct roffsu *, void *);
typedef size_t (*tbl_strlen)(const char *, void *);
typedef size_t (*tbl_len)(size_t, void *);
struct rofftbl {
+ tbl_sulen sulen; /* calculate scaling unit length */
tbl_strlen slen; /* calculate string length */
tbl_len len; /* produce width of empty space */
struct roffcol *cols; /* master column specifiers */
- void *arg; /* passed to slen and len */
+ void *arg; /* passed to sulen, slen, and len */
};
#define SCALE_VS_INIT(p, v) \